.. dreamtim documentation master file, created by
   sphinx-quickstart on Tue Apr  5 13:37:30 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to dreamtim's documentation!
====================================

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   dreamtim


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
